@@ -1,6 +1,6 @@
-<?php
+<?php declare(strict_types=1);
 /*
- * This file is part of the PHP_Invoker package.
+ * This file is part of php-invoker.
  *
  * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
@@ -8,9 +8,8 @@
  * file that was distributed with this source code.
  */
 
-/**
- * @since      Class available since Release 1.0.0
- */
-class PHP_Invoker_TimeoutException extends RuntimeException
+namespace SebastianBergmann\Invoker;
+
+final class TimeoutException extends \RuntimeException implements Exception
 {
 }
